exceptiontools.MusicContentsError
=================================

.. inheritance-diagram:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MusicContentsError.MusicContentsError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
